%define anolis_release 3
%bcond_with doc_pdf
%bcond_without tests
%global pypi_name pyrsistent

Name:           python-%{pypi_name}
Summary:        Persistent/Immutable/Functional data structures for Python
Version:        0.19.3
Release:        %{anolis_release}%{dist}
License:        MIT AND BSD-3-Clause
URL:            https://github.com/tobgu/%{pypi_name}/
Source0:        https://github.com/tobgu/%{pypi_name}/archive/v%{version}/%{pypi_name}-%{version}.tar.gz

BuildRequires:  python%{python3_pkgversion}-devel python%{python3_pkgversion}-hypothesis python%{python3_pkgversion}-pip python%{python3_pkgversion}-wheel
BuildRequires:  pyproject-rpm-macros
BuildRequires:  gcc

%if %{with doc_pdf}
BuildRequires:  make python%{python3_pkgversion}-sphinx-latex latexmk
%endif

%if %{with tests}
BuildRequires:  python%{python3_pkgversion}-pytest
%endif

%description
Pyrsistent is a number of persistent collections (by some referred to as
functional data structures). Persistent in the sense that they are
immutable.

Pyrsistent is influenced by persistent data structures such as those found
in the standard library of Clojure. The data structures are designed to
share common elements through path copying. It aims at taking these concepts
and make them as pythonic as possible so that they can be easily integrated
into any python program without hassle.


%package -n     python%{python3_pkgversion}-%{pypi_name}
Summary:        Persistent/Immutable/Functional data structures for Python

%description -n python%{python3_pkgversion}-%{pypi_name}
Pyrsistent is a number of persistent collections (by some referred to as
functional data structures). Persistent in the sense that they are
immutable.

Pyrsistent is influenced by persistent data structures such as those found
in the standard library of Clojure. The data structures are designed to
share common elements through path copying. It aims at taking these concepts
and make them as pythonic as possible so that they can be easily integrated
into any python program without hassle.


%package        doc
Summary:        Documentation files for %{name}
BuildArch:      noarch

%description doc
The %{name}-doc package contains documentation files for %{name}.


%prep
%autosetup -n %{pypi_name}-%{version} -p1
sed -r \
    -e 's/==/>=/' \
    -e '/\b(memory-profiler|psutil|pyperform|tox|twine)\b/d' \
    requirements.txt | tee requirements-filtered.txt

%generate_buildrequires
%pyproject_buildrequires requirements-filtered.txt

%build
%pyproject_wheel
%if %{with doc_pdf}
PYTHONPATH="${PWD}" %make_build -C docs latex SPHINXOPTS='-n %{?_smp_mflags}'
%make_build -C docs/build/latex LATEXMKOPTS='-quiet'
%endif


%install
%pyproject_install
%pyproject_save_files %{pypi_name} _%{pypi_name}_version pvectorc


%if %{with tests}
%check
%pytest
%pytest --doctest-modules %{pypi_name}
%endif


%files -n python%{python3_pkgversion}-%{pypi_name} -f %{pyproject_files}
%license LICENSE.mit


%files doc
%doc CHANGES.txt README.rst
%if %{with doc_pdf}
%doc docs/build/latex/Pyrsistent.pdf
%endif


%changelog
* Mon Mar 25 2024 Zhao Hang <wb-zh951434@alibaba-inc.com> - 0.19.3-3
- Rebuild with python3.11

* Sat Apr 08 2023 Shawn Wang <shawnwang@linux.alibaba.com> - 0.19.3-2
- Optimize the spec file

* Thu Feb 02 2023 mgb01105731 <mgb01105731@alibaba-inc.com> - 0.19.3-1
- update to version 0.19.3

* Tue Apr 19 2022 Zhongling He <zhonglingh@linux.alibaba.com> 0.18.1-1
- Init package from upstream v0.18.1
